/*
 * Copyright 2009 SpringSource
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.bundlor.support.contributors;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.util.Arrays;
import java.util.Set;

import org.junit.Test;
import org.osgi.framework.Constants;

import com.springsource.bundlor.support.ArtifactAnalyzer;
import com.springsource.bundlor.support.partialmanifest.StandardReadablePartialManifest;
import com.springsource.bundlor.util.SimpleManifestContents;
import com.springsource.util.parser.manifest.ManifestContents;

public class BundleClassPathArtifactAnalyzerTests {

    private final BundleClassPathArtifactAnalyzer analyzer;

    public BundleClassPathArtifactAnalyzerTests() {
        this.analyzer = new BundleClassPathArtifactAnalyzer(Arrays.<ArtifactAnalyzer> asList(new StaticResourceArtefactAnalyser()));
    }

    @Test
    public void canAnalyze() {
        assertTrue(this.analyzer.canAnalyse("test.jar"));
        assertFalse(this.analyzer.canAnalyse("test.properties"));
    }

    @Test
    public void analyze() throws FileNotFoundException, Exception {
        StandardReadablePartialManifest partialManifest = new StandardReadablePartialManifest();
        this.analyzer.analyse(new FileInputStream("src/test/resources/com/springsource/bundlor/support/contributors/test.jar"), "test.jar",
            partialManifest);
        partialManifest.condense();
        Set<String> exportedPackages = partialManifest.getExportedPackages();
        assertEquals(1, exportedPackages.size());
        assertTrue(exportedPackages.contains("com.springsource.test"));

        ManifestContents manifest = new SimpleManifestContents();
        this.analyzer.contribute(manifest);
        String entry = manifest.getMainAttributes().get(Constants.BUNDLE_CLASSPATH);
        assertNotNull(entry);
        assertEquals(".,test.jar", entry);
    }
}
